<!-- Code generated by gomarkdoc. DO NOT EDIT -->

# cache

```go
import "github.com/Qithub-BOT/QiiTrans/src/cache"
```

Package cache は key\-value 型の簡易 DB です\.

New\(\) でインスタンスが作成されると、テンポラリ・ディレクトリにキャッシュ用のディレクトリを作成します。 主に "Set\(\<翻訳前テキスト\>\, \<翻訳後テキスト\>\)" のように、翻訳結果をキャッシュするのに使われます。 デフォルトで共通のキャッシュ・ディレクトリを利用します。異なるキャッシュにしたい場合は任意のキャッシュ ID を指定します。

```
myCache := cache.New("myCache")
```

主なメソッド

```
Set(key, value) ... キャッシュの作成・更新をします
Get(key) ... キャッシュから値を取得します。
ClearAll() ... キャッシュ・ディレクトリを削除します。
```

## Index

- [Constants](<#constants>)
- [type TCache](<#type-tcache>)
  - [func New(cacheID ...string) *TCache](<#func-new>)
  - [func (c *TCache) ClearAll()](<#func-tcache-clearall>)
  - [func (c *TCache) CloseDB()](<#func-tcache-closedb>)
  - [func (c *TCache) Get(key string) (string, error)](<#func-tcache-get>)
  - [func (c *TCache) GetPathDirCache() string](<#func-tcache-getpathdircache>)
  - [func (c *TCache) GetValueInByte(keyHashed []byte) ([]byte, error)](<#func-tcache-getvalueinbyte>)
  - [func (c *TCache) OpenDB() (err error)](<#func-tcache-opendb>)
  - [func (c *TCache) Set(key string, value string) (err error)](<#func-tcache-set>)
  - [func (c *TCache) hash64(content string) []byte](<#func-tcache-hash64>)


## Constants

NameDirCacheDefault はキャッシュ時のデフォルトのディレクトリ名もしくはプレフィックス（接頭辞）です\.

テンポラリ・ディレクトリの、この名前の付いたディレクトリは削除可能です\.

```go
const NameDirCacheDefault = "QiiTrans"
```

## type [TCache](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.go#L11-L15>)

TCache はキャッシュ DB の構造体です\. \[badger\]\(https://github.com/dgraph-io/badger\) のラッパーです\.

```go
type TCache struct {
    cacheDB      *badger.DB
    NameDirCache string
    PathDirTemp  string
}
```

### func [New](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/New.go#L10>)

```go
func New(cacheID ...string) *TCache
```

New は TCache の新規オブジェクトのポインタを返します\. デフォルトで共通のキャッシュを利用します。各々異なるキャッシュにしたい場合は、引数に ID を指定します\.

<details><summary>Example</summary>
<p>

```go
package main

import (
	"fmt"
	"github.com/Qithub-BOT/QiiTrans/src/cache"
)

func main() {
	// 汎用のキャッシュにしたくない場合は ID を指定する。この場合は "my sample DB".
	c := cache.New("my sample DB")

	// 終了時にキャッシュを削除したい場合は defer で ClearAll する
	defer c.ClearAll()

	phraseOriginal := "Hello, world!"
	phraseTranslated := "世界よ、こんにちは！"

	// Set でキャッシュに登録
	_ = c.Set(phraseOriginal, phraseTranslated)

	// Get でキャッシュから取得
	result, _ := c.Get(phraseOriginal)

	fmt.Println(result)
}
```

#### Output

```
世界よ、こんにちは！
```

</p>
</details>

### func \(\*TCache\) [ClearAll](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.ClearAll.go#L10>)

```go
func (c *TCache) ClearAll()
```

ClearAll はキャッシュ・データを削除します\.

### func \(\*TCache\) [CloseDB](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.CloseDB.go#L11>)

```go
func (c *TCache) CloseDB()
```

CloseDB はキャッシュの DB をクローズします\. DB がオープンされていない場合は何もしません\. クローズに失敗した場合はパニックを起こします\.

このメソッドは、Get\(\) Set\(\) でも呼び出されるため、利用時に OpenDB\(\) CloseDB\(\) を行う必要はありません\.

### func \(\*TCache\) [Get](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.Get.go#L5>)

```go
func (c *TCache) Get(key string) (string, error)
```

Get はキャッシュから key を探索し、その値を文字列で返します\. キャッシュに key がない場合はエラーを返します\.

### func \(\*TCache\) [GetPathDirCache](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.GetPathDirCache.go#L6>)

```go
func (c *TCache) GetPathDirCache() string
```

GetPathDirCache は現在のキャッシュ先のディレクトリを返します\.

### func \(\*TCache\) [GetValueInByte](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.GetValueInByte.go#L6>)

```go
func (c *TCache) GetValueInByte(keyHashed []byte) ([]byte, error)
```

GetValueInByte はバイトデータにハッシュ化された keyHashed キーを使ってキャッシュを探索しバイトデータで返します\.

### func \(\*TCache\) [OpenDB](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.OpenDB.go#L11>)

```go
func (c *TCache) OpenDB() (err error)
```

OpenDB はキャッシュ用の DB をオープンします\. キャッシュ・ディレクトリが存在しない場合は、テンポラリディレクトリに新規に作成します\.

このメソッドは、Get\(\) Set\(\) でも呼び出されるため、利用時に OpenDB\(\) CloseDB\(\) を行う必要はありません\.

### func \(\*TCache\) [Set](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.Set.go#L11>)

```go
func (c *TCache) Set(key string, value string) (err error)
```

Set は value の値を key に割り当ててキャッシュします\.

引数 key は、内部で 64 バイトの固定長にハッシュ化されるため、長さに依存しません\. この関数は、主に翻訳前の文と、翻訳後の文のキャッシュに使われます\. 呼び出しごとにキャッシュ DB を open/close するため、大量の連続呼び出しには向きません\. 大量に登録する場合は SetList\(\) 関数を利用してください\.

### func \(\*TCache\) [hash64](<https://github.com/Qithub-BOT/QiiTrans/blob/main/src/cache/TCache.hash64.go#L6>)

```go
func (c *TCache) hash64(content string) []byte
```

hash64 は content の内容を 64 バイトのハッシュ値に変換します\.

------

Generated by [gomarkdoc](<https://github.com/princjef/gomarkdoc>)
